Learn R Programming

SDALGCP (version 0.4.0)

confint.SDALGCP: Confidence Intervals for SDALGCP Model Parameters

Description

Computes confidence intervals for one or more parameters in a fitted SDALGCP model from the object of class "SDALGCP", based on asymptotic normality.

Usage

# S3 method for SDALGCP
confint(object, parm, level = 0.95, dp = 3, ...)

Arguments

object

an object of class "SDALGCP" obtained as result of a call to SDALGCPMCML.

parm

a specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.

level

the confidence level required.

dp

the number of decimal places for the result

...

additional argument(s) for methods.

Value

A matrix (or vector) with columns giving lower and upper confidence limits for each parameter. These will be labelled as (1-level)/2 and 1 - (1-level)/2 in

See Also

confint.lm, confint.default, SDALGCPMCML