Learn R Programming

SDALGCP (version 0.4.0)

pop_den: Population density raster shapefile of Newcastle Upon Tyne in the UK.

Description

A dataset containing the population density of Newcastle upon Tyne of 300 X 300 metres

Usage

data(pop_den)

Arguments

Format

This is a raster file of population density, 300 X 300 meters.

References

Murdock, A.P., Harfoot, A.J.P., Martin, D., Cockings, S. and Hill, C. (2015) OpenPopGrid: an open gridded population dataset for England and Wales. GeoData, University of Southampton.