This function performs Monte Carlo maximum likelihood (MCML) estimation for the geostatistical Poisson model with log link function.
Aggregated_poisson_log_MCML(
y,
D,
m,
corr,
par0,
control.mcmc,
S.sim,
Denominator,
messages
)the data
the design matrix
the offset term
the correlation matrix from exponential correlation function
the initial parameter of the fixed effects beta, the variance sigmasq and the scale parameter phi, specified as c(beta, sigma2, phi)
output from controlmcmcSDA.
the posterior sample of the linear predictor given the initial parameters
the value of the denominator of the likelihood
logical; if message=TRUE, it prints the results objective function and the parameters at every phi iteration. Default is FALSE.
estimate: estimates of the model parameters; beta's and with sigma2 on the log scale
covariance: covariance matrix of the MCML estimates.
log.lik: maximum value of the log-likelihood.
S: the linear predictor given the initial parameter
The function helps to obtain the MCML estimate for a given value of correlation matrix, i.e for a given value of the scale parameter phi.
Giorgi, E., & Diggle, P. J. (2017). PrevMap: an R package for prevalence mapping. Journal of Statistical Software, 78(8), 1-29. doi:10.18637/jss.v078.i08.
Christensen, O. F. (2004). Monte Carlo maximum likelihood in model-based geostatistics. Journal of Computational and Graphical Statistics 13, 702-718.